6. About — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- previous |
- Umbra 1.0.4 documentation »

# 6. About

Umbra by Thomas Mansencal – 2010 - 2012
Copyright© 2010 - 2012 – Thomas Mansencal – thomas.mansencal@gmail.com
This software is released under terms of GNU GPL V3 license: http://www.gnu.org/licenses/
http://www.thomasmansencal.com/

### Navigation

- index
- modules |
- previous |
- Umbra 1.0.4 documentation »